﻿// #######################################################################################################
// Program Name: CCR Server.exe
// Author: Steve Vandenbush (modified by Brice Hilgemann)
// Last Modified: 3/10/2010
// Status: Finalized
// Usage: Allows a user to select a COM port of which is then utilized for the main program to communicate
//        with the track.  Code taken from Steve Vandenbush's PortSelect.cs for communication between the
//        RS232 serial - to - USB adapter.
// #######################################################################################################

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;                                 // Standard includes
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace Server
{
    public partial class ComSelect : Form
    {
// @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
//     BEGINNING OF GLOBAL VARIABLES
// @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@


// @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
//     BEGINNING OF CODE AND EVENTS - DEFAULTS AND INITIALIZATION
// @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

        public ComSelect()
        // ################################################################################################################
        //   Standard Form Initialization
        // ################################################################################################################
        {
            InitializeComponent();
        }

        private void ComSelect_Shown(object sender, EventArgs e)
        // ################################################################################################################
        //   Set up defaults at startup when form is first shown
        // ################################################################################################################
        {
            refreshButton_Click(null, null);                   // Initially do refresh of the available COM ports

            timer1.Enabled = true;                             // Setup timer to automatically refresh every 5 seconds
            timer1.Interval = 5000;
        }
    
        private void form1_FormClosed(object sender, FormClosedEventArgs e)
        // ################################################################################################################
        //   Closes form after Form1 is selected
        // ################################################################################################################
        {
            try
            {
                this.Close();
            }
            catch { }
        }

        private void refreshButton_KeyDown(object sender, KeyEventArgs e)
        // ################################################################################################################
        //   If user hits 'Enter' on refresh button, call Refresh
        // ################################################################################################################
        {
            if (e.KeyCode == Keys.Enter)
            {
                refreshButton_Click(null, null);
            }
        }

        private void portSelectButton_KeyDown(object sender, KeyEventArgs e)
        // ################################################################################################################
        //   If user hits 'Enter' on select button, call Select
        // ################################################################################################################
        {
            if (e.KeyCode == Keys.Enter)
            {
                portSelectButton_Click(null, null);
            }
        }

        private void timer1_Tick(object sender, EventArgs e)
        // ################################################################################################################
        //   Timer that will refresh the available Ports
        // ################################################################################################################
        {
            refreshButton_Click(null, null);
        }


// @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
//     BEGINNING OF CODE FOR BUTTONS AND ITEM CLICKS
// @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

        private void disconnectToolStripMenuItem_Click(object sender, EventArgs e)
        // ################################################################################################################
        //   User clicked to disconnect - close form
        // ################################################################################################################
        {
            Application.Exit();
        }

        private void refreshButton_Click(object sender, EventArgs e)
        // ################################################################################################################
        //   Refreshes the COM port that is available on the laptop
        // ################################################################################################################
        {
            availablePorts.Items.Clear();                      // Clear listbox

            foreach (string PortNames in System.IO.Ports.SerialPort.GetPortNames())
            {
                availablePorts.Items.Add(PortNames);           // Add the ports to the list
            }

            if (availablePorts.Items.Count > 0)                // Select the first index is there is one
            {
                availablePorts.SelectedIndex = 0;
            }
            else if (availablePorts.Items.Count <= 0)
            {
                MessageBox.Show("No Ports Available");
            }
        }

        private void portSelectButton_Click(object sender, EventArgs e)
        // ################################################################################################################
        //   User has clicked 'Select' - start the next Form
        // ################################################################################################################
        {
            if (availablePorts.SelectedIndex >= 0)                                    // If they selected something, launch
            {
                string select = availablePorts.SelectedItem.ToString();
                timer1.Enabled = false;                                               // Stop the timer
                //Form1 form1 = new Form1(select);
                //form1.FormClosed += new FormClosedEventHandler(form1_FormClosed);     // To close this upon form1 closure
                //form1.Show();                                                         // Show new form
                //this.Hide();                                                          // Hide this form
            }
            else
            {
                MessageBox.Show("No Selection Made");
            }
        }
    }
}